Test File

# Purpose

The purpose of this file is to show off the functionality of `alloypress`.

## Markdown Support

`Alloypress` supports the original markdown syntax:

- bold and italic text
- links
- and so on...

## Latex Support

Beyond that, it also supports inline equations via `latex2mathml`, such as C(S t, K, t), as well as block equations:

C(S t, K, t)=S t N(d 1)−K e−r(T−t)N(d 2)

## Syntax Highlighting

It also supports syntax highlighting for python:

    def fizzbuzz(n):
        for i in range(1, n+1):
            if i % 15 == 0:
                print("fizzbuzz")
            elif i % 3 == 0:
                print("fizz")
            elif i % 5 == 0:
                print("buzz")
            else:
                print(i)

## Sidenotes

It also supports sidenotessuch as this, which are displayed inline on narrow devices.